/* config.h.  Generated by configure.  */
/*
 * FCRON - periodic command scheduler
 *
 *  Copyright 2000-2006 Thibault Godouet <fcron@free.fr>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  The GNU General Public License can also be found in the file
 *  `LICENSE' that comes with the fcron source distribution.
 */

 /* $Id: config.h,v 1.2 2006/08/19 19:26:55 nprasad Exp $ */


/* *********************************************************** */
/* This file is destined to be edited to match your preference */
/* *********************************************************** */


/* ****************************************************************** */
/* beginning of configurable stuff ********************************** */


/* fcron allow, deny and conf files are located in directory ETC (see below) */
#define FCRON_ALLOW      "fcron.allow"
#define FCRON_DENY       "fcron.deny"
#define FCRON_CONF       "fcron.conf"

#define SENDMAIL_ARGS	 "-Ffcron", "-odi"   /* args of mail command */

/* *** time *** */
#define FIRST_SLEEP 20        /* fcron sleep at least this time after startup
			       * before executing a job, to avoid to run jobs
			       * during system boot */

#define LAVG_SLEEP 30         /* the time we sleep when some jobs are in lavg queue */

#define SAVE            1800  /* save every n seconds */

/* *** behavior *** */
#define SERIAL_ONCE 0 /* can a job be several times in the serial queue at
		       * the same moment ? */

#define LAVG_ONCE 1 /* can a job be several times in the lavg queue at
		     * the same moment ? */

#define MAXYEAR_SCHEDULE_TIME 10 /* a job can't be scheduled further than
                             * now + MAXYEAR_SCHEDULE years. This is used
                             * to prevent infinite loop on corrupted lines */

/* *** memory *** */
#define EXE_INITIAL_SIZE 6 /* initial number of possible running job
			    * if more jobs have to be run simultaneously,
			    * fcron will have to calloc() more memory */
#define EXE_GROW_SIZE 5 /* this is the number of entries that will be
			 * added to exe_array each time it has to grow
			 * up */

#define SERIAL_QUEUE_MAX 30 /* if serial queue contains this number of entries,
			     * the next serial job to be executed will be run
			     * non-serially each time a serial job is added */
#define SERIAL_INITIAL_SIZE 10 /* initial number of possible serial job. If
				* more jobs have to be in queue simultaneously,
				* fcron will have to calloc() more memory */
#define SERIAL_GROW_SIZE 10 /* this is the number of entries that will be
			     * added to serial queue each time it has to grow
			     * up */

#define SERIAL_MAX_RUNNING 1 /* fcron will run (by default) no more than this
			      * number of serial job simultaneously.
			      * (this may be overridden by fcron option -m */

#define LAVG_QUEUE_MAX 30 /* if lavg queue contains this number of entries,
			   * the next lavg job to be executed will be run
			   * before a new lavg job is added */
#define LAVG_INITIAL_SIZE 10 /* initial number of possible lavg job. If
			      * more jobs have to be in queue simultaneously,
			      * fcron will have to calloc() more memory */
#define LAVG_GROW_SIZE 10 /* this is the number of entries that will be
			   * added to lavg queue each time it has to grow
			   * up */


#define MAXENTRIES  256  /* max lines in non-root fcrontabs */

#define LINE_LEN    1024     /* max line length in user's config file */
#define USER_NAME_LEN 128    /* max length of a user name */
#define PATH_LEN 512         /* max length of a file path */
#define SOCKET_MSG_LEN 20    /* max length of a socket msg (fcrondyn) */

/* WARNING : do not set this too low, or add some more tests in print_field, print_line,
 *           etc ... */
#define TERM_LEN 196         /* max nb of char in a term line */

#define MAX_MSG 175          /* max length of a log message */

#define WRITE_BUF_LEN 1024   /* length of the buffer used for saving files to disk */


/* *** socket *** */
#define MAX_CONNECTION 25    /* max simultaneous connection allowed */
#define MAX_IDLE_TIME 600    /* time (in sec) a socket stay idle before being closed */
#define MAX_AUTH_TIME 60     /* time (in sec) before a socket is closed if not auth'ed */
#define MAX_WAIT_TIME 10     /* time (in sec) we wait for data on a socket */
#define MAX_AUTH_FAIL 10     /* auth nobody for some time if more than x fails */
#define AUTH_WAIT 60         /* if too many fails, wait this time (seconds) before auth
                              * another client */


/* *** system dependent *** */
#define EXIT_ERR   1         /* code returned by fcron/fcrontab on error */
#define EXIT_OK    0         /* code returned  on normal exit */


/* Syslog facility and priorities messages will be logged to (see syslog(3)) */

/* NOTE : if you change anything here, check if the doc should not
          be updated
*/
#define SYSLOG_FACILITY LOG_CRON
#define EXPLAIN_LEVEL LOG_NOTICE  /* informational messages */
#define WARNING_LEVEL LOG_WARNING /* warning messages */
#define COMPLAIN_LEVEL LOG_ERR    /* error messages */
#define DEBUG_LEVEL LOG_DEBUG     /* only used when DEBUG is defined */


/* end of configurable stuff **************************************** */
/* ****************************************************************** */


/* ****************************************************************** */
/* *** options which are set by configure script ******************** */

/* The following should not be edited manually (use configure options)
 * If you must do it, BEWARE : some of the following is also defined
 * in the Makefile, so you must modify config.h AND Makefile in order
 * to set the same values in the two files. */

#define VERSION_QUOTED "3.0.1"
#define COPYRIGHT_QUOTED "2000-2006"

#define CFLAGS "-O2 -Wall"

/* *** paths *** */
#define ETC "/etc"
#define SBINDIREX "/usr/sbin"
#define BINDIREX "/usr/bin"
#define FCRONTABS "/var/spool/fcron"
#define SENDMAIL "/usr/sbin/sendmail"
#undef SENDMAIL /* tf1 */
/* #undef PROC */
/* default editor */
#define EDITOR "/usr/bin/vi"
/* default shell */
#define SHELL "/bin/sh"
/* where is located pid file ? */
#define PIDFILE "/var/run/fcron.pid"
/* where is located fifo file ? */
#define FIFOFILE "/var/run/fcron.fifo"

/* 1 if we want to compile and install fcrondyn */
#define FCRONDYN "1"
/* #undef NOLOADAVG */
/* 1 if you want debug mode */
/* #undef DEBUG */
/* 1 if you want foreground mode by default */
/* #undef FOREGROUND */
/* #undef RUN_NON_PRIVILEGED */

/* Define if we should use sete[ug]id() funcs */
#define USE_SETE_ID 1

/* root uid, gid, name and group */
#define ROOTUID 0
#define ROOTGID 0
#define ROOTNAME "root"
#define ROOTGROUP "root"

/* user and group name to run under */
#define USERNAME "root"
#define GROUPNAME "root"

/* special user for the system fcrontab */
#define SYSFCRONTAB "systab"

/* Define to empty if the keyword does not work.  */
/* #undef const */

/* Define to `int' if <sys/types.h> doesn't define.  */
/* #undef gid_t */

/* Define to `int' if <sys/types.h> doesn't define.  */
/* #undef pid_t */

/* Define to `unsigned' if <sys/types.h> doesn't define.  */
/* #undef size_t */

/* Define to `int' if <sys/types.h> doesn't define.  */
/* #undef uid_t */

/* Define as the return type of signal handlers (int or void).  */
#define RETSIGTYPE void

/* Define if your struct nlist has an n_un member.  */
/* #undef NLIST_NAME_UNION */

/* Define for DGUX with <sys/dg_sys_info.h>.  */
/* #undef DGUX */

/* Define for Encore UMAX.  */
/* #undef UMAX */

/* Define for Encore UMAX 4.3 that has <inq_status/cpustats.h>
   instead of <sys/cpustats.h>.  */
/* #undef UMAX4_3 */

/* Define on System V Release 4.  */
/* #undef SVR4 */

/* Define if you have the crypt function.  */
#define HAVE_CRYPT 1

/* Define if you have the flock function.  */
#define HAVE_FLOCK 1

/* Define if you have the lockf function.  */
#define HAVE_LOCKF 1

/* Define if your system has its own `getloadavg' function.  */
#define HAVE_GETLOADAVG 1

/* Define if the `getloadavg' function needs to be run setuid or setgid.  */
/* #undef GETLOADAVG_PRIVILEGED */

/* Define if you have the getcwd function.  */
#define HAVE_GETCWD 1

/* Define if you have the gethostname function.  */
#define HAVE_GETHOSTNAME 1

/* Define if you have the getopt_long function.  */
#define HAVE_GETOPT_LONG 1

/* Define if you have the gettimeofday function.  */
#define HAVE_GETTIMEOFDAY 1

/* Define if you have the kstat* functions.  */
/* #undef HAVE_KSTAT */

/* Define if you have the mkstemp function.  */
#define HAVE_MKSTEMP 1

/* Define if you have the mktime function.  */
#define HAVE_MKTIME 1

/* Define if you have the putenv function.  */
#define HAVE_PUTENV 1

/* Define if you have the setenv function.  */
#define HAVE_SETENV 1

/* Define if you have the setegid function.  */
#define HAVE_SETEGID 1

/* Define if you have the seteuid function.  */
#define HAVE_SETEUID 1

/* Define if you have the setlinebuf function.  */
#define HAVE_SETLINEBUF 1

/* Define if you have the setpriority function.  */
#define HAVE_SETPRIORITY 1

/* Define if you have the strerror function.  */
#define HAVE_STRERROR 1

/* Define if you have the setresgid function.  */
#define HAVE_SETRESGID 1

/* Define if you have the setresuid function.  */
#define HAVE_SETRESUID 1

/* Define if you have the signal function.  */
#define HAVE_SIGNAL 1

/* Define if you have the sigset function.  */
#define HAVE_SIGSET 1

/* Define if you have the strftime function.  */
#define HAVE_STRFTIME 1

/* Define if you have the wait3 system call.  */
#define HAVE_WAIT3 1

/* Define if you have the ANSI C header files.  */
#define STDC_HEADERS 1

/* Define if you can safely include both <sys/time.h> and <time.h>.  */
#define TIME_WITH_SYS_TIME 1

/* Define if your <sys/time.h> declares struct tm.  */
/* #undef TM_IN_SYS_TIME */

/* Define if you have the <crypt.h> header file.  */
#define HAVE_CRYPT_H 1

/* Define if you have the <dirent.h> header file.  */
#define HAVE_DIRENT_H 1

/* Define if you have the <errno.h> header file.  */
#define HAVE_ERRNO_H 1

/* Define if you have the <fcntl.h> header file.  */
#define HAVE_FCNTL_H 1

/* Define if you have the <getopt.h> header file.  */
#define HAVE_GETOPT_H 1

/* Define if you have the <grp.h> header file.  */
#define HAVE_GRP_H 1

/* Define if you have the <limits.h> header file.  */
#define HAVE_LIMITS_H 1

/* Define if you have the <mach/mach.h> header file.  */
/* #undef HAVE_MACH_MACH_H */

/* Define if you have the <ndir.h> header file.  */
/* #undef HAVE_NDIR_H */

/* Define if you have the <pam/pam_appl.h> header file.  */
/* #undef HAVE_PAM_PAM_APPL_H */

/* Define if you have <shadow.h>.  */
#define HAVE_SHADOW_H 1

/* Define if you have <nlist.h>.  */
/* #undef NLIST_STRUCT */

/* Define if you have the <security/pam_appl.h> header file.  */
/* #undef HAVE_SECURITY_PAM_APPL_H */

/* Define if you have the <stdarg.h> header file.  */
#define HAVE_STDARG_H 1

/* Define if you have the <strings.h> header file.  */
#define HAVE_STRINGS_H 1

/* Define if you have the <sys/dir.h> header file.  */
/* #undef HAVE_SYS_DIR_H */

/* Define if you have the <sys/fcntl.h> header file.  */
#define HAVE_SYS_FCNTL_H 1

/* Define if you have the <sys/file.h> header file.  */
#define HAVE_SYS_FILE_H 1

/* Define if you have the <sys/ioctl.h> header file.  */
#define HAVE_SYS_IOCTL_H 1

/* Define if you have the <sys/ndir.h> header file.  */
/* #undef HAVE_SYS_NDIR_H */

/* Define if you have the <sys/resource.h> header file.  */
#define HAVE_SYS_RESOURCE_H 1

/* Define if you have the <sys/socket.h> header file.  */
#define HAVE_SYS_SOCKET_H 1

/* Define if you have the <sys/termios.h> header file.  */
#define HAVE_SYS_TERMIOS_H 1

/* Define if you have the <sys/time.h> header file.  */
#define HAVE_SYS_TIME_H 1

/* Define if you have the <sys/types.h> header file.  */
#define HAVE_SYS_TYPES_H 1

/* Define if you have the <sys/un.h> header file.  */
#define HAVE_SYS_UN_H 1

/* Define if you have <sys/wait.h> that is POSIX.1 compatible.  */
#define HAVE_SYS_WAIT_H 1

/* Define if you have the <syslog.h> header file.  */
#define HAVE_SYSLOG_H 1

/* Define if you have the <unistd.h> header file.  */
#define HAVE_UNISTD_H 1

/* Define if you have the dgc library (-ldgc).  */
/* #undef HAVE_LIBDGC */

/* Define if you have the pam library (-lpam).  */
/* #undef HAVE_LIBPAM */

/* Define if you have the shadow library (-lshadow or included in c library).  */
#define HAVE_LIBSHADOW 1

/* Have SE Linux support */
/* #undef WITH_SELINUX */

/* Define if you have the xnet library (-lxnet).  */
/* #undef HAVE_LIBXNET */

/* some systems (*BSD, ...) use O_FSYNC instead of O_SYNC for open() */
#ifdef HAVE_FCNTL_H
#include <fcntl.h>
#elif HAVE_SYS_FCNTL_H
#include <sys/fcntl.h>
#endif
#ifndef O_SYNC
#define O_SYNC O_FSYNC
#endif

